# Minimal required versions
%define nspr_version 4.8
%define nss_version 3.12.6
%define cairo_version 1.6.0
%define freetype_version 2.1.9
%define tarballdir mozilla-1.9.2

%define version_internal  1.9.2
%define mozappdir         %{_libdir}/%{name}-%{version_internal}

# Separated plugins are supported on x86(64) only
%ifarch i386 x86_64
%define separated_plugins 1
%else
%define separated_plugins 0
%endif

Summary:        XUL Runtime for Gecko Applications
Name:           xulrunner
Version:        1.9.2.7
Release:        3.0.1%{?pretag}%{?dist}
URL:            http://developer.mozilla.org/En/XULRunner
License:        MPLv1.1 or GPLv2+ or LGPLv2+
Group:          Applications/Internet
# You can get sources at ftp://ftp.mozilla.org/pub/firefox/releases/%{version}%{?pretag}/source
Source0:        %{name}-%{version}%{?pretag}.source.tar.bz2
Source10:       %{name}-mozconfig
Source12:       %{name}-oracle-default-prefs.js
Source21:       %{name}.sh.in
Source23:       %{name}.1

# build patches
Patch0:         xulrunner-version.patch
Patch1:         mozilla-build.patch
Patch3:         mozilla-jemalloc.patch
Patch4:         mozilla-about-firefox-version.patch
Patch7:         xulrunner-1.9.2.1-build.patch
Patch8:         mozilla-plugin.patch
Patch9:         mozilla-build-sbrk.patch
Patch10:        camelia.patch
Patch17:        xulrunner-gtkmozembed-compatibility.patch
Patch20:        mozilla-build-s390.patch
Patch22:        xulrunner-ipc-stl.patch

# Fedora specific patches
Patch50:        mozilla-192-pkgconfig.patch

# Upstream patches
Patch100:       mozilla-ps-pdf-simplify-operators.patch
Patch101:       mozilla-546270.patch
Patch102:       mozilla-575836.patch

# ---------------------------------------------------

BuildRoot:      %(mktemp -ud %{_tmppath}/%{name}-%{version}-%{release}-XXXXXX)
BuildRequires:  nspr-devel >= %{nspr_version}
BuildRequires:  nss-devel >= %{nss_version}
BuildRequires:  libjpeg-devel
BuildRequires:  zip
BuildRequires:  bzip2-devel
BuildRequires:  zlib-devel
BuildRequires:  libIDL-devel
BuildRequires:  gtk2-devel
BuildRequires:  gnome-vfs2-devel
BuildRequires:  libgnome-devel
BuildRequires:  libgnomeui-devel
BuildRequires:  krb5-devel
BuildRequires:  pango-devel
BuildRequires:  freetype-devel >= %{freetype_version}
BuildRequires:  libXt-devel
BuildRequires:  libXrender-devel
BuildRequires:  startup-notification-devel
BuildRequires:  alsa-lib-devel
BuildRequires:  libnotify-devel
BuildRequires:  autoconf213

#Requires:       mozilla-filesystem
Requires:       nspr >= %{nspr_version}
Requires:       nss >= %{nss_version}
Provides:       gecko-libs = %{version}
Conflicts:      firefox < 3.6

%description
XULRunner provides the XUL Runtime environment for Gecko applications.

%package devel
Summary: Development files for Gecko
Group: Development/Libraries
Obsoletes: mozilla-devel < 1.9
Obsoletes: firefox-devel < 2.1
Obsoletes: xulrunner-devel-unstable
Provides: gecko-devel = %{version}
Provides: gecko-devel-unstable = %{version}

Requires: xulrunner = %{version}-%{release}
Requires: nspr-devel >= %{nspr_version}
Requires: nss-devel >= %{nss_version}
Requires: libjpeg-devel
Requires: zip
Requires: bzip2-devel
Requires: zlib-devel
Requires: libIDL-devel
Requires: gtk2-devel
Requires: gnome-vfs2-devel
Requires: libgnome-devel
Requires: libgnomeui-devel
Requires: krb5-devel
Requires: pango-devel
Requires: freetype-devel >= %{freetype_version}
Requires: libXt-devel
Requires: libXrender-devel
Requires: startup-notification-devel
Requires: alsa-lib-devel
Requires: libnotify-devel

%description devel
Gecko development files.

#---------------------------------------------------------------------

%prep
%setup -q -c
cd %{tarballdir}

sed -e 's/__RPM_VERSION_INTERNAL__/%{version_internal}/' %{P:%%PATCH0} \
    > version.patch
%{__patch} -p1 -b --suffix .version --fuzz=0 < version.patch

%patch1  -p1 -b .build
%patch3  -p1 -b .jemalloc
%patch4  -p1 -b .about-firefox-version
%patch7  -p2 -b .del
%patch8  -p1 -b .plugin
%patch9  -p2 -b .sbrk
%patch10 -p1 -b .cam
%patch17 -p1 -b .gtkmozembed
%ifarch s390
%patch20 -p1 -b .s390
%endif
%patch22 -p1 -b .stl

%patch50 -p1 -b .pk

%patch100 -p1 -b .ps-pdf-simplify-operators
%patch101 -p1 -b .546270
%patch102 -p1 -b .575836


%{__rm} -f .mozconfig
%{__cp} %{SOURCE10} .mozconfig

%if !%{?separated_plugins}
echo "ac_add_options --disable-ipc" >> .mozconfig
%endif

#---------------------------------------------------------------------

%build
cd %{tarballdir}

INTERNAL_GECKO=%{version_internal}
MOZ_APP_DIR=%{_libdir}/%{name}-${INTERNAL_GECKO}

# Mozilla builds with -Wall with exception of a few warnings which show up
# everywhere in the code; so, don't override that.
MOZ_OPT_FLAGS=$(echo $RPM_OPT_FLAGS | %{__sed} -e 's/-Wall//')
export CFLAGS=$MOZ_OPT_FLAGS
export CXXFLAGS=$MOZ_OPT_FLAGS

export PREFIX='%{_prefix}'
export LIBDIR='%{_libdir}'

MOZ_SMP_FLAGS=-j1
%ifnarch ppc ppc64 s390 s390x
[ -z "$RPM_BUILD_NCPUS" ] && \
     RPM_BUILD_NCPUS="`/usr/bin/getconf _NPROCESSORS_ONLN`"
[ "$RPM_BUILD_NCPUS" -gt 1 ] && MOZ_SMP_FLAGS=-j2
%endif

export LDFLAGS="-Wl,-rpath,${MOZ_APP_DIR}"
make -f client.mk build STRIP="/bin/true" MOZ_MAKE_FLAGS="$MOZ_SMP_FLAGS"

#---------------------------------------------------------------------

%install
cd %{tarballdir}
%{__rm} -rf $RPM_BUILD_ROOT

INTERNAL_GECKO=%{version_internal}

INTERNAL_APP_NAME=%{name}-${INTERNAL_GECKO}
MOZ_APP_DIR=%{_libdir}/${INTERNAL_APP_NAME}

INTERNAL_APP_SDK_NAME=%{name}-sdk-${INTERNAL_GECKO}
MOZ_APP_SDK_DIR=%{_libdir}/${INTERNAL_APP_SDK_NAME}

DESTDIR=$RPM_BUILD_ROOT make install

%{__mkdir_p} $RPM_BUILD_ROOT/${MOZ_APP_DIR} \
             $RPM_BUILD_ROOT%{_datadir}/idl/${INTERNAL_APP_SDK_NAME} \
             $RPM_BUILD_ROOT%{_includedir}/${INTERNAL_APP_SDK_NAME}
%{__install} -p dist/sdk/bin/regxpcom $RPM_BUILD_ROOT/$MOZ_APP_DIR

%{__mkdir_p} $RPM_BUILD_ROOT{%{_libdir},%{_bindir},%{_datadir}/applications}

# set up our default preferences
%{__cat} %{SOURCE12} | %{__sed} -e 's,RPM_VERREL,%{version}-%{release},g' > rh-default-prefs
%{__install} -p -D -m 644 rh-default-prefs $RPM_BUILD_ROOT/${MOZ_APP_DIR}/defaults/pref/all-redhat.js
%{__rm} rh-default-prefs

# Start script install
%{__rm} -rf $RPM_BUILD_ROOT%{_bindir}/%{name}
%{__cat} %{SOURCE21} | %{__sed} -e 's,XULRUNNER_VERSION,%{version_internal},g' > \
  $RPM_BUILD_ROOT%{_bindir}/%{name}
%{__chmod} 755 $RPM_BUILD_ROOT%{_bindir}/%{name}

%{__rm} -f $RPM_BUILD_ROOT${MOZ_APP_DIR}/%{name}-config

cd $RPM_BUILD_ROOT${MOZ_APP_DIR}/chrome
find . -name "*" -type d -maxdepth 1 -exec %{__rm} -rf {} \;
cd -

# system extensions and plugins support
%{__mkdir_p} $RPM_BUILD_ROOT%{_datadir}/mozilla/extensions
%{__mkdir_p} $RPM_BUILD_ROOT%{_libdir}/mozilla/extensions
%{__mkdir_p} $RPM_BUILD_ROOT%{_libdir}/mozilla/plugins
%{__mkdir_p} $RPM_BUILD_ROOT%{_sysconfdir}/skel/.mozilla/extensions
%{__mkdir_p} $RPM_BUILD_ROOT%{_sysconfdir}/skel/.mozilla/plugins

# Prepare our devel package
%{__mkdir_p} $RPM_BUILD_ROOT/%{_includedir}/${INTERNAL_APP_SDK_NAME}
%{__mkdir_p} $RPM_BUILD_ROOT/%{_datadir}/idl/${INTERNAL_APP_SDK_NAME}
%{__mkdir_p} $RPM_BUILD_ROOT/%{_libdir}/pkgconfig

%{__cp} -rL dist/include/* \
  $RPM_BUILD_ROOT/%{_includedir}/${INTERNAL_APP_SDK_NAME}

# Copy pc files (for compatibility with 1.9.1)
%{__cp} $RPM_BUILD_ROOT/%{_libdir}/pkgconfig/libxul.pc \
        $RPM_BUILD_ROOT/%{_libdir}/pkgconfig/libxul-unstable.pc
%{__cp} $RPM_BUILD_ROOT/%{_libdir}/pkgconfig/libxul-embedding.pc \
        $RPM_BUILD_ROOT/%{_libdir}/pkgconfig/libxul-embedding-unstable.pc

# Fix multilib devel conflicts...
%ifarch x86_64 ia64 s390x ppc64
%define mozbits 64
%else
%define mozbits 32
%endif

function install_file() {
genheader=$*
mv ${genheader}.h ${genheader}%{mozbits}.h
cat > ${genheader}.h << EOF
/* This file exists to fix multilib conflicts */
#if defined(__x86_64__) || defined(__ia64__) || defined(__s390x__) || defined(__powerpc64__)
#include "${genheader}64.h"
#else
#include "${genheader}32.h"
#endif
EOF
}

pushd $RPM_BUILD_ROOT/%{_includedir}/${INTERNAL_APP_SDK_NAME}
install_file "mozilla-config"
popd

pushd $RPM_BUILD_ROOT/%{_includedir}/${INTERNAL_APP_SDK_NAME}
install_file "jsautocfg"
popd

pushd $RPM_BUILD_ROOT/%{_includedir}/${INTERNAL_APP_SDK_NAME}
install_file "js-config"
popd

%{__install} -p -c -m 755 dist/bin/xpcshell \
  dist/bin/xpidl \
  dist/bin/xpt_dump \
  dist/bin/xpt_link \
  $RPM_BUILD_ROOT/${MOZ_APP_DIR}

%{__rm} -rf $RPM_BUILD_ROOT/%{_includedir}/${INTERNAL_APP_NAME}
%{__rm} -rf $RPM_BUILD_ROOT/%{_datadir}/idl/${INTERNAL_APP_NAME}

%{__rm} -rf $RPM_BUILD_ROOT${MOZ_APP_SDK_DIR}/include
ln -s  %{_includedir}/${INTERNAL_APP_SDK_NAME} \
       $RPM_BUILD_ROOT${MOZ_APP_SDK_DIR}/include

%{__rm} -rf $RPM_BUILD_ROOT${MOZ_APP_SDK_DIR}/idl
ln -s  %{_datadir}/idl/${INTERNAL_APP_SDK_NAME} \
       $RPM_BUILD_ROOT${MOZ_APP_SDK_DIR}/idl

%{__rm} -rf $RPM_BUILD_ROOT${MOZ_APP_SDK_DIR}/sdk/include
ln -s  %{_includedir}/${INTERNAL_APP_SDK_NAME} \
       $RPM_BUILD_ROOT${MOZ_APP_SDK_DIR}/sdk/include

%{__rm} -rf $RPM_BUILD_ROOT${MOZ_APP_SDK_DIR}/sdk/idl
ln -s  %{_datadir}/idl/${INTERNAL_APP_SDK_NAME} \
       $RPM_BUILD_ROOT${MOZ_APP_SDK_DIR}/sdk/idl

find $RPM_BUILD_ROOT/%{_includedir} -type f -name "*.h" | xargs chmod 644
find $RPM_BUILD_ROOT/%{_datadir}/idl -type f -name "*.idl" | xargs chmod 644

%{__rm} -rf $RPM_BUILD_ROOT${MOZ_APP_SDK_DIR}/sdk/lib/*.so
pushd $RPM_BUILD_ROOT${MOZ_APP_DIR}
for i in *.so; do
    ln -s ${MOZ_APP_DIR}/$i $RPM_BUILD_ROOT${MOZ_APP_SDK_DIR}/sdk/lib/$i
done
popd

# GRE stuff
%ifarch x86_64 ia64 ppc64 s390x
%define gre_conf_file gre64.conf
%else
%define gre_conf_file gre.conf
%endif

MOZILLA_GECKO_VERSION=`./config/milestone.pl --topsrcdir=.`
%{__mv} $RPM_BUILD_ROOT/etc/gre.d/$MOZILLA_GECKO_VERSION".system.conf" \
        $RPM_BUILD_ROOT/etc/gre.d/%{gre_conf_file}
chmod 644 $RPM_BUILD_ROOT/etc/gre.d/%{gre_conf_file}

# Library path
%ifarch x86_64 ia64 ppc64 s390x
%define ld_conf_file xulrunner-64.conf
%else
%define ld_conf_file xulrunner-32.conf
%endif

%{__mkdir_p} $RPM_BUILD_ROOT/etc/ld.so.conf.d
%{__cat} > $RPM_BUILD_ROOT/etc/ld.so.conf.d/%{ld_conf_file} << EOF
${MOZ_APP_DIR}
EOF

# Copy over the LICENSE
%{__install} -p -c -m 644 LICENSE $RPM_BUILD_ROOT${MOZ_APP_DIR}

# Use the system hunspell dictionaries
%{__rm} -rf ${RPM_BUILD_ROOT}${MOZ_APP_DIR}/dictionaries
ln -s %{_datadir}/myspell ${RPM_BUILD_ROOT}${MOZ_APP_DIR}/dictionaries

# ghost files
%{__mkdir_p} $RPM_BUILD_ROOT${MOZ_APP_DIR}/components
touch $RPM_BUILD_ROOT${MOZ_APP_DIR}/components/compreg.dat
touch $RPM_BUILD_ROOT${MOZ_APP_DIR}/components/xpti.dat

#---------------------------------------------------------------------

%clean
%{__rm} -rf $RPM_BUILD_ROOT

#---------------------------------------------------------------------

%post
/sbin/ldconfig

%postun
/sbin/ldconfig

%preun
# is it a final removal?
if [ $1 -eq 0 ]; then
  %{__rm} -rf ${MOZ_APP_DIR}/components
fi

%files
%defattr(-,root,root,-)
%{_bindir}/xulrunner
%{_libdir}/mozilla
%{_datadir}/mozilla
%dir /etc/gre.d
/etc/gre.d/%{gre_conf_file}
%dir %{mozappdir}
%doc %attr(644, root, root) %{mozappdir}/LICENSE
%doc %attr(644, root, root) %{mozappdir}/README.txt
%{mozappdir}/chrome
%dir %{mozappdir}/components
%ghost %{mozappdir}/components/compreg.dat
%ghost %{mozappdir}/components/xpti.dat
%{mozappdir}/components/*.so
%{mozappdir}/components/*.xpt
%attr(644, root, root) %{mozappdir}/components/*.js
%{mozappdir}/defaults
%{mozappdir}/greprefs
%dir %{mozappdir}/icons
%attr(644, root, root) %{mozappdir}/icons/*
%{mozappdir}/modules
%{mozappdir}/plugins
%{mozappdir}/res
%{mozappdir}/*.so
%{mozappdir}/mozilla-xremote-client
%{mozappdir}/run-mozilla.sh
%{mozappdir}/regxpcom
%{mozappdir}/xulrunner
%{mozappdir}/xulrunner-bin
%{mozappdir}/xulrunner-stub
%{mozappdir}/platform.ini
%{mozappdir}/dependentlibs.list
%{_sysconfdir}/ld.so.conf.d/xulrunner*.conf
%{_sysconfdir}/skel/.mozilla
# XXX See if these are needed still
%{mozappdir}/updater*
%exclude %{mozappdir}/update.locale
%exclude %{mozappdir}/components/components.list
%exclude %{mozappdir}/dictionaries
%if %{?separated_plugins}
%{mozappdir}/plugin-container
%endif

%files devel
%defattr(-,root,root,-)
%dir %{_libdir}/%{name}-sdk-*
%dir %{_libdir}/%{name}-sdk-*/sdk
%dir %{_datadir}/idl/%{name}*%{version_internal}
%{_datadir}/idl/%{name}*%{version_internal}
%{_includedir}/%{name}*%{version_internal}
%{_libdir}/%{name}-sdk-*/*
%{_libdir}/%{name}-sdk-*/sdk/*
%{_libdir}/pkgconfig/*.pc
%{mozappdir}/xpcshell
%{mozappdir}/xpidl
%{mozappdir}/xpt_dump
%{mozappdir}/xpt_link

#---------------------------------------------------------------------

%changelog
* Sun Jul 25 2010 Kevin Lyons <kevin.x.lyons@oracle.com> - 1.9.2.7-3.0.1.el5
- Added xulrunner-oracle-default-prefs.js and removed the corresponding
  RedHat one.

* Fri Jul 23 2010 Christopher Aillon <caillon@redhat.com> - 1.9.2.7-3
- Include fix for 575836

* Wed Jul 14 2010 Jan Horak <jhorak@redhat.com> - 1.9.2.7-2
- Update to build 2

* Thu Jul 1 2010 Martin Stransky <stransky@redhat.com> 1.9.2.7-1
- Update to 1.9.2.7

* Thu Jun 24 2010 Christopher Aillon <caillon@redhat.com> - 1.9.2.4-10
- Fix a file dependency issue

* Mon Jun 14 2010 Jan Horak <jhorak@redhat.com> - 1.9.2.4-9
- Update to 1.9.2.4 build 7

* Tue Jun 1 2010 Martin Stransky <stransky@redhat.com> 1.9.2.4-8
- Update to 1.9.2.4 build 6

* Mon May 25 2010 Martin Stransky <stransky@redhat.com> 1.9.2.4-7
- Update to 1.9.2.4 build 5

* Mon May 17 2010 Martin Stransky <stransky@redhat.com> 1.9.2.4-6
- Update to 1.9.2.4 build 4
- Fixed mozbz#546270 patch

* Thu May  6 2010 Jan Horak <jhorak@redhat.com> - 1.9.2.4-5
- Update to 1.9.2.4 build 3

* Mon May 3 2010 Martin Stransky <stransky@redhat.com> 1.9.2.4-4
- Update to 1.9.2.4 build 2
- Enabled oopp

* Fri Apr 23 2010 Martin Stransky <stransky@redhat.com> 1.9.2.4-3
- Disabled libnotify

* Fri Apr 23 2010 Martin Stransky <stransky@redhat.com> 1.9.2.4-2
- Disabled oopp, causes TEXTREL

* Mon Apr 19 2010 Martin Stransky <stransky@redhat.com> 1.9.2.4-1
- Update to 1.9.2.4

* Mon Apr 12 2010 Martin Stransky <stransky@redhat.com> 1.9.2.3-3
- fixed js-config.h multilib conflict
- fixed file list

* Mon Apr 12 2010 Martin Stransky <stransky@redhat.com> 1.9.2.3-2
- Added fix for rhbz#555760 -  Firefox Javascript anomily, 
  landscape print orientation reverts to portrait (mozbz#546270)

* Sat Apr 3 2010 Martin Stransky <stransky@redhat.com> 1.9.2.3-1
- Update to 1.9.2.3

* Fri Apr 2 2010 Martin Stransky <stransky@redhat.com> 1.9.2.2-1
- Rebase to 1.9.2.2

* Thu Apr 23 2009 Christopher Aillon <caillon@redhat.com> - 1.9.0.10-1
- Update to 1.9.0.10

* Fri Apr 10 2009 Jan Horak <jhorak@redhat.com> - 1.9.0.9-1
- Update to 1.9.0.9

* Thu Mar 26 2009 Martin Stransky <stransky@redhat.com> - 1.9.0.7-3
- Updated per 1.9.0.8

* Thu Feb 19 2009 Jan Horak <jhorak@redhat.com> - 1.9.0.7-1
- Update to 1.9.0.7

* Wed Jan 21 2009 Jan Horak <jhorak@redhat.com> - 1.9.0.6-1
- Update to 1.9.0.6

* Tue Dec 9 2008 Martin Stransky <stransky@redhat.com> 1.9.0.5-1
- Update to 1.9.0.5

* Wed Nov 5 2008 Martin Stransky <stransky@redhat.com> 1.9.0.4-1
- Update to 1.9.0.4

* Thu Sep 18 2008 Martin Stransky <stransky@redhat.com> 1.9.0.2-6
- Enabled safe-browsing (#463157)

* Thu Sep 18 2008 Martin Stransky <stransky@redhat.com> 1.9.0.2-5
- Update to 1.9.0.2 build 6

* Wed Sep 3 2008 Martin Stransky <stransky@redhat.com> 1.9.0.2-4
- Fixed firefox dependency (#445391)

* Wed Sep 3 2008 Martin Stransky <stransky@redhat.com> 1.9.0.2-3
- Update to 1.9.0.2 build 4

* Fri Aug 29 2008 Martin Stransky <stransky@redhat.com> 1.9.0.2-2
- Fixed gecko version

* Fri Aug 29 2008 Martin Stransky <stransky@redhat.com> 1.9.0.2-1
- Update to 1.9.0.2

* Fri Jul 11 2008 Martin Stransky <stransky@redhat.com> 1.9.0.1-2
- Updated provided gecko version

* Thu Jul 10 2008 Martin Stransky <stransky@redhat.com> 1.9.0.1-1
- Update to 1.9.0.1

* Sun Jun 15 2008 Christopher Aillon <caillon@redhat.com> 1.9-1
- Update to 1.9 final

* Fri Apr 25 2008 Martin Stransky <stransky@redhat.com> 1.9-0.beta5.6
- Fixed build regression on ppc64

* Wed Apr 23 2008 Christopher Aillon <caillon@redhat.com> 1.9-0.beta5.5
- Bump internal cairo to 1.6.4

* Tue Apr 16 2008 Christopher Aillon <caillon@redhat.com> 1.9-0.beta5.4
- Don't be as agressive with DPI scaling
- Allow overrides of SEC_ERROR_INADEQUATE_KEY_USAGE

* Wed Apr 09 2008 Christopher Aillon <caillon@redhat.com> 1.9-0.beta5.3
- Resolve multilib conflicts in -devel

* Fri Apr 04 2008 Martin Stransky <stransky@redhat.com> 1.9-0.beta5.1
- Update to Beta 5.

* Tue Mar 25 2008 Martin Stransky <stransky@redhat.com> 1.9-0.beta4.2
- updated to latest trunk (2008-03-24)
- avoid conflict between gecko debuginfos
- removed unused patches

* Wed Mar 05 2008 Martin Stransky <stransky@redhat.com> 1.9-0.beta4.1
- updated to latest trunk (2008-03-05)

* Tue Mar 04 2008 Martin Stransky <stransky@redhat.com> 1.9-0.beta3.3
- removed global library registration
- build with embeded sqlite, don't break the system library

* Wed Feb 20 2008 Martin Stransky <stransky@redhat.com> 1.9-0.beta3.2
- version bump
- fixed documentation file rights

* Wed Feb 20 2008 Martin Stransky <stransky@redhat.com> 1.9-0.beta2.11
- updated to latest trunk (2008-02-17)
- enabled gnome vfs
- added debuginfo packages fix

* Mon Feb 04 2008 Martin Stransky <stransky@redhat.com> 1.9-0.beta2.10
- updated to latest trunk (2008-01-30)
- removed unnecessary patches
- fixed broken symlinks in gecko-devel
- disabled system jpeg library

* Thu Jan 17 2008 Martin Stransky <stransky@redhat.com> 1.9-0.beta2.9
- added patches for moz bugs 311008,412068,410852
- disabled startup notification
- updated pkg-config files with libdir variable

* Wed Jan 9 2008 Martin Stransky <stransky@redhat.com> 1.9-0.beta2.8
- updated requires

* Mon Jan 7 2008 Martin Stransky <stransky@redhat.com> 1.9-0.beta2.7
- removed fedora specific pkg-config files
- updated to the latest trunk (2008-01-07)
- removed unnecessary patches
- fixed idl dir (#427965)

* Thu Jan 3 2008 Christopher Aillon <caillon@redhat.com> 1.9-0.beta2.6
- Re-enable camellia256 support now that NSS supports it

* Thu Jan 3 2008 Martin Stransky <stransky@redhat.com> 1.9-0.beta2.5
- updated to the latest trunk (2008-01-03)

* Mon Dec 24 2007 Christopher Aillon <caillon@redhat.com> 1.9-0.beta2.4
- Don't Provide webclient (xulrunner is not itself a webclient)
- Don't Obsolete old firefox, only firefox-devel
- Kill legacy obsoletes (phoenix, etc) that were never in rawhide

* Thu Dec 21 2007 Martin Stransky <stransky@redhat.com> 1.9-0.beta2.3
- added java and plugin subdirs to plugin includes

* Thu Dec 20 2007 Martin Stransky <stransky@redhat.com> 1.9-0.beta2.2
- dependency fixes, obsoletes firefox < 3 and firefox-devel now

* Wed Dec 12 2007 Martin Stransky <stransky@redhat.com> 1.9-0.beta2.1
- updated to Beta 2.
- moved SDK to xulrunner-sdk

* Thu Dec 06 2007 Martin Stransky <stransky@redhat.com> 1.9-0.beta1.4
- fixed mozilla-plugin.pc (#412971)

* Tue Nov 27 2007 Martin Stransky <stransky@redhat.com> 1.9-0.beta1.3
- export /etc/gre.d/gre.conf (it's used by python gecko applications)

* Mon Nov 26 2007 Martin Stransky <stransky@redhat.com> 1.9-0.beta1.2
- added xulrunner/js include dir to xulrunner-js

* Tue Nov 20 2007 Martin Stransky <stransky@redhat.com> 1.9-0.beta1.1
- update to beta 1

* Mon Nov 19 2007 Martin Stransky <stransky@redhat.com> 1.9-0.alpha9.6
- packed all gecko libraries (#389391)

* Thu Nov 15 2007 Martin Stransky <stransky@redhat.com> 1.9-0.alpha9.5
- registered xulrunner libs system-wide
- added xulrunner-gtkmozembed.pc

* Wed Nov 14 2007 Martin Stransky <stransky@redhat.com> 1.9-0.alpha9.4
- added proper nss/nspr dependencies

* Wed Nov 14 2007 Martin Stransky <stransky@redhat.com> 1.9-0.alpha9.3
- more build fixes, use system nss libraries

* Tue Nov 6 2007 Martin Stransky <stransky@redhat.com> 1.9-0.alpha9.2
- build fixes

* Tue Oct 30 2007 Martin Stransky <stransky@redhat.com> 1.9-0.alpha9.1
- updated to the latest trunk

* Thu Sep 20 2007 David Woodhouse <dwmw2@infradead.org> 1.9-0.alpha7.4
- build fixes for ppc/ppc64

* Tue Sep 20 2007 Martin Stransky <stransky@redhat.com> 1.9-0.alpha7.3
- removed conflicts with the current gecko-based apps
- added updated ppc64 patch

* Tue Sep 18 2007 Martin Stransky <stransky@redhat.com> 1.9-0.alpha7.2
- build fixes

* Wed Sep  5 2007 Christopher Aillon <caillon@redhat.com> 1.9-0.alpha7.1
- Initial cut at XULRunner 1.9 Alpha 7
- Temporarily revert camellia 256 support since our nss doesn't support it yet
